#include <LiquidCrystal_I2C.h>
LiquidCrystal_I2C lcd(0x27, 16, 2);

const int CO2A0 = A0;
const int SoundA1 = A1;
const int ledPin = 13;
int CO2value = 0;

// Define custom characters for smiley and sad faces
byte smiley[8] = {
  0b00000,
  0b01010,
  0b01010,
  0b00000,
  0b00000,
  0b10001,
  0b01110,
  0b00000
};

byte sad[8] = {
  0b00000,
  0b01010,
  0b01010,
  0b00000,
  0b00000,
  0b01110,
  0b10001,
  0b00000
};

void setup() {
  lcd.init(); 
  lcd.backlight();
  Serial.begin(9600);

  // Create custom characters
  lcd.createChar(1, smiley);
  lcd.createChar(2, sad);

  pinMode(SoundA1, INPUT);  // Set SoundA1 as input
  pinMode(ledPin, OUTPUT);  // Set ledPin as output

  lcd.setCursor(0, 0);
  lcd.print("Initializing... ");  // Initialization message
  lcd.setCursor(0, 1);
  lcd.print("                ");  // Clear line 2

  for (int i = 0; i <= 100; i++) {  // Display percentage from 1 to 100
    lcd.setCursor(12, 1);
    lcd.print(i);
    lcd.print("% ");
    delay(150);
  }

  delay(2000);
  lcd.clear();
}

void loop() {
  int analogSensorCO2 = analogRead(CO2A0);  // Read from A0
  CO2value = map(analogSensorCO2, 0, 1023, 0, 100);  // CO2 module sensitivity

  int analogSensorSound = digitalRead(SoundA1);  // Read from A1

  // Convert the analog reading to voltage for CO2
  float voltageCO2 = analogSensorCO2 * (5.0 / 1023.0);

  Serial.print("Analog Sound Sensor Value: ");
  Serial.println(analogSensorSound);

  lcd.setCursor(0, 0);
  lcd.print("CO2 Level:");
  lcd.setCursor(11, 0);
  lcd.print(CO2value);
  lcd.print("% ");

  // Checks if it has reached the threshold value
  if (CO2value >= 30) {  // CO2 percentage alert
    lcd.setCursor(0, 1);
    lcd.print("DANGER!   ");
    lcd.write(2);  // Display sad face 
    digitalWrite(ledPin, HIGH);
  } else if (CO2value >= 20 && CO2value < 30) {
    lcd.setCursor(0, 1);
    lcd.print("BAD!      ");
    lcd.write(2);  // Display sad face
  } else {
    lcd.setCursor(0, 1);
    lcd.print("NORMAL    ");
    lcd.write(1);  // Display smiley face
    digitalWrite(ledPin, LOW);
  } 


    Serial.println(analogSensorSound);
  if (analogSensorSound == 1) {
      digitalWrite(ledPin, LOW);
      lcd.clear();
      lcd.setCursor(0, 0);
      lcd.print("Purificator");
      lcd.setCursor(0, 1);
      lcd.print("started!");
      delay(5000);
      lcd.clear();
  }

}